//Astronomical data from the article:
//"A terrestrial planet candidate in a temperate orbit around Proxima Centauri"
//Url: https://www.eso.org/public/archives/releases/sciencepapers/eso1629/eso1629a.pdf
//Authors credits at the end of this file

//Notice that only mass, discovery date, method and orbit parameters are real

//Procedural Venus like

Planet	"Proxima b"
{
	ParentBody     "Proxima"
	Class	       "Desert"

	Mass		1.27
	Radius 		6900.6			//with the earth mean density
	
	DiscDate    "2016.07.13"	//paper date
    DiscMethod  "RadVel"

	EqAscendNode    45.0139
	TidalLocked     true

	AlbedoBond      0.26746
	AlbedoGeom      0.320953
	Brightness      0.45
	Color          (0.890 0.871 0.306)

		Surface
	{
		SurfStyle       0.42381
		OceanStyle      0.190476
		Randomize      (-0.794, 1.079, -0.952)
		colorDistMagn   0.0582208
		colorDistFreq   671.949
		detailScale     17887.4
		drivenDarkening -1
		seaLevel        0.16011
		snowLevel       1
		tropicLatitude  0.749384
		icecapLatitude  0
		icecapHeight    0
		climatePole     0
		climateTropic   0.3125
		climateEquator  0.6875
		heightTempGrad  0.625
		tropicWidth     0.5
		mainFreq        2.89683
		venusFreq       1
		venusMagn       2.85714
		mareFreq        0.019307
		mareDensity     0.222222
		terraceProb     0.130201
		erosion         0.134921
		montesMagn      0.714286
		montesFreq      130
		montesSpiky     1
		montesFraction  0.1
		dunesMagn       0.4
		dunesFreq       42.8571
		dunesFraction   0.238095
		hillsMagn       1.34921
		hillsFreq       182.54
		hillsFraction   0.15873
		hills2Fraction  0.0952381
		riversMagn      65.873
		riversFreq      8.73016
		riversSin       6.96825
		riversOctaves   3
		canyonsMagn     2.53968
		canyonsFreq     47
		canyonFraction  0
		cracksMagn      0.0793651
		cracksFreq      0.596614
		cracksOctaves   0
		craterMagn      0.952381
		craterFreq      4.28571
		craterDensity   0.015873
		craterOctaves   9
		craterRayedFactor 0
		volcanoMagn     0.587187
		volcanoFreq     0.752381
		volcanoDensity  0.65873
		volcanoOctaves  3
		volcanoActivity 2
		volcanoFlows    1
		volcanoRadius   1
		volcanoTemp     2095.24
		lavaCoverTidal  0
		lavaCoverSun    0
		lavaCoverYoung  0
		stripeZones     0.555556
		stripeFluct     0.0952381
		stripeTwist     0.1
		cycloneMagn     1.90476
		cycloneFreq     0.111111
		cycloneDensity  0.0396825
		cycloneOctaves  1
		colorSea       (0.640, 0.620, 0.420, 0.000)
		colorShelf     (0.680, 0.620, 0.470, 0.000)
		colorBeach     (0.740, 0.730, 0.610, 0.000)
		colorDesert    (0.450, 0.420, 0.380, 0.000)
		colorLowland   (0.530, 0.480, 0.400, 0.000)
		colorUpland    (0.600, 0.540, 0.420, 0.000)
		colorRock      (0.170, 0.160, 0.160, 0.000)
		colorSnow      (1.000, 1.000, 1.000, 0.769)
		colorLowPlants (0.530, 0.480, 0.400, 0.000)
		colorUpPlants  (0.600, 0.540, 0.420, 0.000)
		BumpHeight      19.1263
		DiffMapAlpha   "Ice"
		SpecBrightWater 0.5
		SpecBrightIce   0.5
		SpecularPower   30
		Hapke           0
		SpotBright      4
		SpotWidth       0.05
		DayAmbient      0.07
	}

	Clouds
	{
		Height          76.0244
		Velocity        -190.476
		BumpHeight      5.45827
		Hapke           0.2
		SpotBright      2
		SpotWidth       0.15
		DayAmbient      2
		ModulateColor  (1.000 1.000 1.000 0.9)
		mainFreq        0.547619
		mainOctaves     3
		Coverage        0.706349
		stripeZones     0.555556
		stripeFluct     0.0952381
		stripeTwist     0.1
	}

	NoOcean         true

	NoLava          true

	Atmosphere
	{
		Model          "Venus"
		Height          124.52
		Density         21544.3
		Pressure        103.95
		Greenhouse      376.19
		Bright          13.8095
		Opacity         0.912698
		SkyLight        3.88889
		Hue             0.0873016
		Saturation      0.857143

		Composition
		{
			N2   	74.5923
			CO2   	9.33788
			SO2   	8.95416
			H2S    	3.60026
			H2O   	1.38987
			Ne    	1.25557
			H2    	0.813473
			CO    	0.0347354
			C2H4  	0.000903388
			C3H8  	0.000403814
			NH3   	0.000376375
			Ar    	0.000347737
			He    	0.000203662
		}
	}

	Aurora
	{
		Height      110.092
		NorthLat    62.762
		NorthLon    -82.7689
		NorthRadius 1651.73
		NorthWidth  498.41
		NorthRings  3
		NorthBright 0.3
		NorthParticles 50000
		SouthLat    -43.4875
		SouthLon    111.254
		SouthRadius 1839.48
		SouthWidth  565.996
		SouthRings  2
		SouthBright 0.3
		SouthParticles 50000
		TopColor    (1.000 1.000 1.000)
		BottomColor (0.000 1.000 0.000)
	}

	NoRings         true

	NoAccretionDisk true

	NoCometTail     true

	Orbit
	{
		RefPlane        "Extrasolar"
		SemiMajorAxis   0.0485
		ArgOfPericenter 310
	}
}


//Authors:
//Guillem Anglada-Escude, Pedro J. Amado, John Barnes,
//Zaira M. Berdi˜nas, R. Paul Butler, Gavin A. L. Coleman,
//Ignacio de la Cueva, Stefan Dreizler, Michael Endl,
//Benjamin Giesers, Sandra V. Jeffers, James S. Jenkins8,
//Hugh R. A. Jones, Marcin Kiraga, Martin Kurster,
//Marıa J. Lopez-Gonzalez, Christopher J. Marvin, Nicolas Morales,
//Julien Morin, Richard P. Nelson, Jose L. Ortiz,
//Aviv Ofir, Sijme-Jan Paardekooper, Ansgar Reiners,
//Eloy Rodriguez, Cristina Rodrıguez-Lopez, Luis F. Sarmiento,
//John P. Strachan, Yiannis Tsapras, Mikko Tuomi,
//Mathias Zechmeister
